pub enum TestError {
ContainsNotSortableValues,
}Expand description
Error that can be raised by a statistical test
Variants
ContainsNotSortableValues
Case when a type to test supports only a partial order and some of the entries are not present in the order sequence (e.g. NaN in floats)